# pyimgtool

Image compression/watermarking using pillow. Useful for photographers to prep files for web sharing.

## Features

- Resize/thumbnail images to maximum or minimum dimensions
- Image watermarking
- Text watermarking
- JPEG compression

## Install

Simply run `pip install pyimgtool`  

## Todo

- Automatically find best region for watermarking
- Set text watermark color based on target region
- Create specific print sizes at 300 dpi
  - Add padding if image is smaller than print size
